==> hence1.3.tgz: hence1.3/pvmrsh/pvm_fput.c <==
#include <stdio.h>
#include <varargs.h>


pvm_fput (va_alist)
va_dcl
{
    char *format;
    int iarg;
    int *iparg;
    long larg;
    long *lparg;
    float *fparg;
    double darg;
    double *dparg;
    char *carg;
    va_list args;
    char *ptr;

    va_start (args);
    format = va_arg (args, char *);
    while (*ptr) {
	if (*ptr == '%') {
	    has_width = 0;
	    width = 0;
	    ++ptr;
	    switch (*ptr) {
	    case 'i':
		if (has_width) {
		    iparg = va_arg (args, int *);
		    putnint (iparg, width);
		}
		else {
		    iarg = va_arg (args, int);
		    putnint (&iarg, 1);
		}
		break;
	    case 'f':
		if (has_width) {
		    fparg = va_arg (args, float *);
		    putnfloat (fparg, width);
		}
		else {
		    darg = va_arg (args, double);
		    putndfloat (&darg, 1);
		}
		break;
	    case 'd':
		if (has_width) {
		    dparg = va_arg (args, double *);
		    putndfloat (dparg, width);
		}
		else {
		    darg = va_arg (args, double);
		    farg = darg;
		    putnfloat (&farg, 1);
		}
		break;
	    case 'c':
		if (has_width) {
		    cparg = va_arg (args, char *);
		    putbytes (cparg, width);
		}
		else {
		    carg = va_arg (args, int);
		    putbytes (&carg, 1);
		}
		break;
	    case 's':
		/* XXX need to handle width somehow */
		cparg = va_arg (args, char *);
		putstring (cparg);
		break;
	    case 'h':
		if (has_width) {
		    hparg = va_arg (args, short int *);
		    putnshort (hparg, width);
		}
		else {
		    iarg = va_arg (args, int);
		    harg = iarg;
		    putnshort (&harg, 1);
		}
		break;
	    
	}
    }
}

==> hence1.4.tgz: hence1.4/pvmrsh/pvm_fput.c <==
#include <stdio.h>
#include <varargs.h>


pvm_fput (va_alist)
va_dcl
{
    char *format;
    int iarg;
    int *iparg;
    long larg;
    long *lparg;
    float *fparg;
    double darg;
    double *dparg;
    char *carg;
    va_list args;
    char *ptr;

    va_start (args);
    format = va_arg (args, char *);
    while (*ptr) {
	if (*ptr == '%') {
	    has_width = 0;
	    width = 0;
	    ++ptr;
	    switch (*ptr) {
	    case 'i':
		if (has_width) {
		    iparg = va_arg (args, int *);
#ifdef PVM3
		    pvm_pkint (iparg, width, 1);
#else
		    putnint (iparg, width);
#endif
		}
		else {
		    iarg = va_arg (args, int);
#ifdef PVM3
		    pvm_pkint (&iarg, 1, 1);
#else
		    putnint (&iarg, 1);
#endif
		}
		break;
	    case 'f':
		if (has_width) {
		    fparg = va_arg (args, float *);
		    putnfloat (fparg, width);
		}
		else {
		    darg = va_arg (args, double);
		    putndfloat (&darg, 1);
		}
		break;
	    case 'd':
		if (has_width) {
		    dparg = va_arg (args, double *);
		    putndfloat (dparg, width);
		}
		else {
		    darg = va_arg (args, double);
		    farg = darg;
		    putnfloat (&farg, 1);
		}
		break;
	    case 'c':
		if (has_width) {
		    cparg = va_arg (args, char *);
#ifdef PVM3
		    pvm_pkbyte (cparg, width, 1);
#else
		    putbytes (cparg, width);
#endif
		}
		else {
		    carg = va_arg (args, int);
#ifdef PVM3
		    pvm_pkbyte (&carg, 1, 1);
#else
		    putbytes (&carg, 1);
#endif
		}
		break;
	    case 's':
		/* XXX need to handle width somehow */
		cparg = va_arg (args, char *);
#ifdef PVM3
		pvm_pkstr (cparg);
#else
		putstring (cparg);
#endif
		break;
	    case 'h':
		if (has_width) {
		    hparg = va_arg (args, short int *);
		    putnshort (hparg, width);
		}
		else {
		    iarg = va_arg (args, int);
		    harg = iarg;
		    putnshort (&harg, 1);
		}
		break;
	    
	}
    }
}
